@@ -1,28 +1,23 @@
+SLEEP_TIME = 100 / 1000
 
 MINIMUM_MESSAGE_SIZE = 6
-
 MAXIMUM_MESSAGE_SIZE = MINIMUM_MESSAGE_SIZE + 8
 
-START_BYTE = 0x0f
-
+START_BYTE = 0x0F
 END_BYTE = 0x04
 
-HIGH_PRIORITY = 0xf8
-FIRMWARE_PRIORITY = 0xf9
-THIRD_PARTY_PRIORITY = 0xfa
-LOW_PRIORITY = 0xfb
-PRIORITY = [HIGH_PRIORITY, FIRMWARE_PRIORITY, THIRD_PARTY_PRIORITY, LOW_PRIORITY] 
+HIGH_PRIORITY = 0xF8
+FIRMWARE_PRIORITY = 0xF9
+THIRD_PARTY_PRIORITY = 0xFA
+LOW_PRIORITY = 0xFB
+PRIORITY = [HIGH_PRIORITY, FIRMWARE_PRIORITY, THIRD_PARTY_PRIORITY, LOW_PRIORITY]
 
 LOW_ADDRESS = 0x00
-
-HIGH_ADDRESS = 0xff
+HIGH_ADDRESS = 0xFF
 
 RTR = 0x40
-
 NO_RTR = 0x00
 
-SIX_CHANNEL_INPUT_MODULE_TYPE = 0x05
-
 ENERGY_KILO_WATT_HOUR: str = "kWh"
 ENERGY_WATT_HOUR: str = "Wh"
 VOLUME_CUBIC_METER: str = "m3"  # Not an official constant at HA yet
